package osservatorio_astronomico_con_liste;

import java.util.*;

public class Osservatorio {
	
	public static final int MAX_CORPI_CELESTI = 100;
	
	private CorpoCeleste[] corpi;
	private int numCorpi;
	private List<Evento> eventi;
	
	public Osservatorio(CorpoCeleste[] corpi, int n, List<Evento> eventi) {
		this.corpi = corpi;
		this.numCorpi = n;
		this.eventi = eventi;
	}
	
	public Osservatorio() {
		this(new CorpoCeleste[MAX_CORPI_CELESTI], 0, new ArrayList<Evento>());
	}
	
	// punto 1)
	public int aggiungiCorpoCeleste(CorpoCeleste corpo) {
		 if(numCorpi < MAX_CORPI_CELESTI) // oppure if(numCorpi < corpi.length)
			 corpi[numCorpi++]=corpo;
		 return numCorpi;
	}
	
	// punto 2)
	public Evento cercaEvento(String data) {
		Evento evento = null;
		boolean trovato = false;
		Iterator<Evento> i = eventi.iterator();
		while(i.hasNext() && !trovato) {
			Evento e = i.next();
			if(e.getData().equals(data)) {
				trovato = true;
				evento = e;
			}
		}
		return evento;
	}
	
	// punto 3)
	public CorpoCeleste cercaCorpoCeleste(String codiceCorpo) {
		CorpoCeleste corpo = null;
		boolean trovato = false;
		for(int i=0; i<numCorpi && !trovato; i++)
			if(corpi[i].getCodice().equals(codiceCorpo)) {
				trovato = true;
				corpo = corpi[i];
			}
		return corpo;
	}
	
	// punto 4)
	public List<TempestaSolare> tempestePericolose(){
		List<TempestaSolare> tempeste = new ArrayList<TempestaSolare>();
		for(int i=0; i < eventi.size(); i++)
			if(eventi.get(i) instanceof TempestaSolare && ((TempestaSolare)eventi.get(i)).pericolosa())
				tempeste.add(((TempestaSolare)eventi.get(i)));
		return tempeste;
	}
	
	// punto 5)
	public CorpoCeleste eclissiInData(String data) {
		CorpoCeleste corpo = null;
		Evento e = cercaEvento(data);
		if(e == null)
			System.out.println("Errore: nessun evento nella data indicata");
		else if(e instanceof Eclissi) 
			corpo = cercaCorpoCeleste(((Eclissi)e).getCodCorpoCeleste());
		else if(e instanceof TempestaSolare)
			System.out.println("Errore: nessuna eclissi nella data indicata");
		return corpo;
	}

}
